# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_tournament.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.dota_client_enums_pb2 as dota__client__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_tournament.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\'dota_gcmessages_client_tournament.proto\x1a\x17\x64ota_client_enums.proto\"\xa6\n\n\x16\x43MsgDOTATournamentInfo\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x31\n\nphase_list\x18\x02 \x03(\x0b\x32\x1d.CMsgDOTATournamentInfo.Phase\x12\x30\n\nteams_list\x18\x03 \x03(\x0b\x32\x1c.CMsgDOTATournamentInfo.Team\x12\x44\n\x15upcoming_matches_list\x18\x04 \x03(\x0b\x32%.CMsgDOTATournamentInfo.UpcomingMatch\x12/\n\tnews_list\x18\x05 \x03(\x0b\x32\x1c.CMsgDOTATournamentInfo.News\x1a\x32\n\nPhaseGroup\x12\x10\n\x08group_id\x18\x01 \x01(\r\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x1a\xba\x01\n\x05Phase\x12\x10\n\x08phase_id\x18\x01 \x01(\r\x12\x12\n\nphase_name\x18\x02 \x01(\t\x12\x0f\n\x07type_id\x18\x03 \x01(\r\x12\x12\n\niterations\x18\x04 \x01(\r\x12\x16\n\x0emin_start_time\x18\x05 \x01(\r\x12\x16\n\x0emax_start_time\x18\x06 \x01(\r\x12\x36\n\ngroup_list\x18\x07 \x03(\x0b\x32\".CMsgDOTATournamentInfo.PhaseGroup\x1aY\n\x04Team\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x11\n\tteam_logo\x18\x04 \x01(\x04\x12\x12\n\neliminated\x18\x05 \x01(\x08\x1a\x89\x05\n\rUpcomingMatch\x12\x11\n\tseries_id\x18\x01 \x01(\r\x12\x10\n\x08team1_id\x18\x02 \x01(\r\x12\x10\n\x08team2_id\x18\x03 \x01(\r\x12\n\n\x02\x62o\x18\x04 \x01(\r\x12\x12\n\nstage_name\x18\x05 \x01(\t\x12\x12\n\nstart_time\x18\x06 \x01(\r\x12\x14\n\x0cwinner_stage\x18\x07 \x01(\t\x12\x13\n\x0bloser_stage\x18\x08 \x01(\t\x12\x11\n\tteam1_tag\x18\t \x01(\t\x12\x11\n\tteam2_tag\x18\n \x01(\t\x12\x1f\n\x17team1_prev_opponent_tag\x18\x0b \x01(\t\x12\x1f\n\x17team2_prev_opponent_tag\x18\x0c \x01(\t\x12\x12\n\nteam1_logo\x18\r \x01(\x04\x12\x12\n\nteam2_logo\x18\x0e \x01(\x04\x12 \n\x18team1_prev_opponent_logo\x18\x0f \x01(\x04\x12 \n\x18team2_prev_opponent_logo\x18\x10 \x01(\x04\x12\x1e\n\x16team1_prev_opponent_id\x18\x11 \x01(\r\x12\x1e\n\x16team2_prev_opponent_id\x18\x12 \x01(\r\x12\x1e\n\x16team1_prev_match_score\x18\x13 \x01(\r\x12\'\n\x1fteam1_prev_match_opponent_score\x18\x14 \x01(\r\x12\x1e\n\x16team2_prev_match_score\x18\x15 \x01(\r\x12\'\n\x1fteam2_prev_match_opponent_score\x18\x16 \x01(\r\x12\x12\n\nphase_type\x18\x17 \x01(\r\x12\x13\n\x0bteam1_score\x18\x18 \x01(\r\x12\x13\n\x0bteam2_score\x18\x19 \x01(\r\x1a\x45\n\x04News\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\r\"#\n!CMsgRequestWeekendTourneySchedule\"\xcc\x01\n\x1a\x43MsgWeekendTourneySchedule\x12\x37\n\tdivisions\x18\x01 \x03(\x0b\x32$.CMsgWeekendTourneySchedule.Division\x1au\n\x08\x44ivision\x12\x15\n\rdivision_code\x18\x01 \x01(\r\x12\x18\n\x10time_window_open\x18\x02 \x01(\r\x12\x19\n\x11time_window_close\x18\x03 \x01(\r\x12\x1d\n\x15time_window_open_next\x18\x04 \x01(\r\"\xc3\x01\n\x16\x43MsgWeekendTourneyOpts\x12\x15\n\rparticipating\x18\x01 \x01(\x08\x12\x13\n\x0b\x64ivision_id\x18\x02 \x01(\r\x12\r\n\x05\x62uyin\x18\x03 \x01(\r\x12\x13\n\x0bskill_level\x18\x04 \x01(\r\x12\x14\n\x0cmatch_groups\x18\x05 \x01(\r\x12\x0f\n\x07team_id\x18\x06 \x01(\r\x12\x18\n\x10pickup_team_name\x18\x07 \x01(\t\x12\x18\n\x10pickup_team_logo\x18\x08 \x01(\x04\"\x19\n\x17\x43MsgWeekendTourneyLeave\"\xe0\x07\n\x12\x43MsgDOTATournament\x12\x15\n\rtournament_id\x18\x01 \x01(\r\x12\x13\n\x0b\x64ivision_id\x18\x02 \x01(\r\x12\x15\n\rschedule_time\x18\x03 \x01(\r\x12\x13\n\x0bskill_level\x18\x04 \x01(\r\x12M\n\x13tournament_template\x18\x05 \x01(\x0e\x32\x14.ETournamentTemplate:\x1ak_ETournamentTemplate_None\x12<\n\x05state\x18\x06 \x01(\x0e\x32\x11.ETournamentState:\x1ak_ETournamentState_Unknown\x12\x15\n\rstate_seq_num\x18\n \x01(\r\x12\x18\n\x10season_trophy_id\x18\x0b \x01(\r\x12\'\n\x05teams\x18\x07 \x03(\x0b\x32\x18.CMsgDOTATournament.Team\x12\'\n\x05games\x18\x08 \x03(\x0b\x32\x18.CMsgDOTATournament.Game\x12\'\n\x05nodes\x18\t \x03(\x0b\x32\x18.CMsgDOTATournament.Node\x1a\xfd\x01\n\x04Team\x12\x10\n\x08team_gid\x18\x01 \x01(\x06\x12\x15\n\rnode_or_state\x18\x02 \x01(\r\x12\x13\n\x07players\x18\x03 \x03(\rB\x02\x10\x01\x12\x18\n\x0cplayer_buyin\x18\t \x03(\rB\x02\x10\x01\x12\x1e\n\x12player_skill_level\x18\n \x03(\rB\x02\x10\x01\x12\x18\n\x10match_group_mask\x18\x0c \x01(\r\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x11\n\tteam_name\x18\x05 \x01(\t\x12\x16\n\x0eteam_base_logo\x18\x07 \x01(\x04\x12\x14\n\x0cteam_ui_logo\x18\x08 \x01(\x04\x12\x11\n\tteam_date\x18\x0b \x01(\r\x1a\xab\x01\n\x04Game\x12\x10\n\x08node_idx\x18\x01 \x01(\r\x12\x10\n\x08lobby_id\x18\x02 \x01(\x06\x12\x10\n\x08match_id\x18\x03 \x01(\x04\x12\x13\n\x0bteam_a_good\x18\x04 \x01(\x08\x12\x44\n\x05state\x18\x05 \x01(\x0e\x32\x15.ETournamentGameState:\x1ek_ETournamentGameState_Unknown\x12\x12\n\nstart_time\x18\x06 \x01(\r\x1a\x8a\x01\n\x04Node\x12\x0f\n\x07node_id\x18\x01 \x01(\r\x12\x12\n\nteam_idx_a\x18\x02 \x01(\r\x12\x12\n\nteam_idx_b\x18\x03 \x01(\r\x12I\n\nnode_state\x18\x04 \x01(\x0e\x32\x15.ETournamentNodeState:\x1ek_ETournamentNodeState_Unknown\"\xbe\x04\n\x1d\x43MsgDOTATournamentStateChange\x12\x19\n\x11new_tournament_id\x18\x01 \x01(\r\x12\x39\n\x05\x65vent\x18\x02 \x01(\x0e\x32\x11.ETournamentEvent:\x17k_ETournamentEvent_None\x12K\n\x14new_tournament_state\x18\x03 \x01(\x0e\x32\x11.ETournamentState:\x1ak_ETournamentState_Unknown\x12?\n\x0cgame_changes\x18\x04 \x03(\x0b\x32).CMsgDOTATournamentStateChange.GameChange\x12?\n\x0cteam_changes\x18\x05 \x03(\x0b\x32).CMsgDOTATournamentStateChange.TeamChange\x12!\n\x15merged_tournament_ids\x18\x06 \x03(\rB\x02\x10\x01\x12\x15\n\rstate_seq_num\x18\x07 \x01(\r\x1ah\n\nGameChange\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12H\n\tnew_state\x18\x02 \x01(\x0e\x32\x15.ETournamentGameState:\x1ek_ETournamentGameState_Unknown\x1aT\n\nTeamChange\x12\x10\n\x08team_gid\x18\x01 \x01(\x04\x12\x19\n\x11new_node_or_state\x18\x02 \x01(\r\x12\x19\n\x11old_node_or_state\x18\x03 \x01(\r\"Q\n\x19\x43MsgDOTATournamentRequest\x12\x15\n\rtournament_id\x18\x01 \x01(\r\x12\x1d\n\x15\x63lient_tournament_gid\x18\x02 \x01(\x04\"X\n\x1a\x43MsgDOTATournamentResponse\x12\x11\n\x06result\x18\x01 \x01(\r:\x01\x32\x12\'\n\ntournament\x18\x02 \x01(\x0b\x32\x13.CMsgDOTATournament\"E\n\x1b\x43MsgDOTAClearTournamentGame\x12\x15\n\rtournament_id\x18\x01 \x01(\r\x12\x0f\n\x07game_id\x18\x02 \x01(\r\"\xf5\x01\n+CMsgDOTAWeekendTourneyPlayerSkillLevelStats\x12\x13\n\x0bskill_level\x18\x01 \x01(\r\x12\x13\n\x0btimes_won_0\x18\x02 \x01(\r\x12\x13\n\x0btimes_won_1\x18\x03 \x01(\r\x12\x13\n\x0btimes_won_2\x18\x04 \x01(\r\x12\x13\n\x0btimes_won_3\x18\x05 \x01(\r\x12\x1a\n\x12times_bye_and_lost\x18\x06 \x01(\r\x12\x19\n\x11times_bye_and_won\x18\x07 \x01(\r\x12\x17\n\x0ftotal_games_won\x18\x08 \x01(\r\x12\r\n\x05score\x18\t \x01(\r\"\xab\x01\n!CMsgDOTAWeekendTourneyPlayerStats\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10season_trophy_id\x18\x02 \x01(\r\x12\x42\n\x0cskill_levels\x18\x03 \x03(\x0b\x32,.CMsgDOTAWeekendTourneyPlayerSkillLevelStats\x12\x14\n\x0c\x63urrent_tier\x18\x04 \x01(\r\"X\n(CMsgDOTAWeekendTourneyPlayerStatsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10season_trophy_id\x18\x02 \x01(\r\"Z\n*CMsgDOTAWeekendTourneyPlayerHistoryRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10season_trophy_id\x18\x02 \x01(\r\"\xcc\x02\n#CMsgDOTAWeekendTourneyPlayerHistory\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x44\n\x0btournaments\x18\x03 \x03(\x0b\x32/.CMsgDOTAWeekendTourneyPlayerHistory.Tournament\x1a\xca\x01\n\nTournament\x12\x15\n\rtournament_id\x18\x01 \x01(\r\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x17\n\x0ftournament_tier\x18\x03 \x01(\r\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x11\n\tteam_date\x18\x05 \x01(\r\x12\x13\n\x0bteam_result\x18\x06 \x01(\r\x12\x12\n\naccount_id\x18\x07 \x03(\r\x12\x11\n\tteam_name\x18\x08 \x01(\t\x12\x18\n\x10season_trophy_id\x18\t \x01(\r\"\xa4\x03\n*CMsgDOTAWeekendTourneyParticipationDetails\x12G\n\tdivisions\x18\x01 \x03(\x0b\x32\x34.CMsgDOTAWeekendTourneyParticipationDetails.Division\x1a\xb3\x01\n\x04Tier\x12\x0c\n\x04tier\x18\x01 \x01(\r\x12\x0f\n\x07players\x18\x02 \x01(\r\x12\r\n\x05teams\x18\x03 \x01(\r\x12\x15\n\rwinning_teams\x18\x04 \x01(\r\x12\x18\n\x10players_streak_2\x18\x05 \x01(\r\x12\x18\n\x10players_streak_3\x18\x06 \x01(\r\x12\x18\n\x10players_streak_4\x18\x07 \x01(\r\x12\x18\n\x10players_streak_5\x18\x08 \x01(\r\x1aw\n\x08\x44ivision\x12\x13\n\x0b\x64ivision_id\x18\x01 \x01(\r\x12\x15\n\rschedule_time\x18\x02 \x01(\r\x12?\n\x05tiers\x18\x03 \x03(\x0b\x32\x30.CMsgDOTAWeekendTourneyParticipationDetails.Tier*\xf5\x03\n\x10\x45TournamentEvent\x12\x1b\n\x17k_ETournamentEvent_None\x10\x00\x12(\n$k_ETournamentEvent_TournamentCreated\x10\x01\x12(\n$k_ETournamentEvent_TournamentsMerged\x10\x02\x12\"\n\x1ek_ETournamentEvent_GameOutcome\x10\x03\x12#\n\x1fk_ETournamentEvent_TeamGivenBye\x10\x04\x12\x30\n,k_ETournamentEvent_TournamentCanceledByAdmin\x10\x05\x12$\n k_ETournamentEvent_TeamAbandoned\x10\x06\x12+\n\'k_ETournamentEvent_ScheduledGameStarted\x10\x07\x12\x1f\n\x1bk_ETournamentEvent_Canceled\x10\x08\x12?\n;k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeRefund\x10\t\x12@\n<k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeForfeit\x10\nB\x05H\x01\x90\x01\x00')
  ,
  dependencies=[dota__client__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ETOURNAMENTEVENT = _descriptor.EnumDescriptor(
  name='ETournamentEvent',
  full_name='ETournamentEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_None', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TournamentCreated', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TournamentsMerged', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_GameOutcome', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TeamGivenBye', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TournamentCanceledByAdmin', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TeamAbandoned', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_ScheduledGameStarted', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_Canceled', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeRefund', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeForfeit', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5037,
  serialized_end=5538,
)
_sym_db.RegisterEnumDescriptor(_ETOURNAMENTEVENT)

ETournamentEvent = enum_type_wrapper.EnumTypeWrapper(_ETOURNAMENTEVENT)
k_ETournamentEvent_None = 0
k_ETournamentEvent_TournamentCreated = 1
k_ETournamentEvent_TournamentsMerged = 2
k_ETournamentEvent_GameOutcome = 3
k_ETournamentEvent_TeamGivenBye = 4
k_ETournamentEvent_TournamentCanceledByAdmin = 5
k_ETournamentEvent_TeamAbandoned = 6
k_ETournamentEvent_ScheduledGameStarted = 7
k_ETournamentEvent_Canceled = 8
k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeRefund = 9
k_ETournamentEvent_TeamParticipationTimedOut_EntryFeeForfeit = 10



_CMSGDOTATOURNAMENTINFO_PHASEGROUP = _descriptor.Descriptor(
  name='PhaseGroup',
  full_name='CMsgDOTATournamentInfo.PhaseGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CMsgDOTATournamentInfo.PhaseGroup.group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_name', full_name='CMsgDOTATournamentInfo.PhaseGroup.group_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=384,
)

_CMSGDOTATOURNAMENTINFO_PHASE = _descriptor.Descriptor(
  name='Phase',
  full_name='CMsgDOTATournamentInfo.Phase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase_id', full_name='CMsgDOTATournamentInfo.Phase.phase_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phase_name', full_name='CMsgDOTATournamentInfo.Phase.phase_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='CMsgDOTATournamentInfo.Phase.type_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='iterations', full_name='CMsgDOTATournamentInfo.Phase.iterations', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_start_time', full_name='CMsgDOTATournamentInfo.Phase.min_start_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_start_time', full_name='CMsgDOTATournamentInfo.Phase.max_start_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_list', full_name='CMsgDOTATournamentInfo.Phase.group_list', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=573,
)

_CMSGDOTATOURNAMENTINFO_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CMsgDOTATournamentInfo.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATournamentInfo.Team.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTATournamentInfo.Team.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTATournamentInfo.Team.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTATournamentInfo.Team.team_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eliminated', full_name='CMsgDOTATournamentInfo.Team.eliminated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=664,
)

_CMSGDOTATOURNAMENTINFO_UPCOMINGMATCH = _descriptor.Descriptor(
  name='UpcomingMatch',
  full_name='CMsgDOTATournamentInfo.UpcomingMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgDOTATournamentInfo.UpcomingMatch.series_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_id', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_id', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bo', full_name='CMsgDOTATournamentInfo.UpcomingMatch.bo', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage_name', full_name='CMsgDOTATournamentInfo.UpcomingMatch.stage_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTATournamentInfo.UpcomingMatch.start_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='winner_stage', full_name='CMsgDOTATournamentInfo.UpcomingMatch.winner_stage', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loser_stage', full_name='CMsgDOTATournamentInfo.UpcomingMatch.loser_stage', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_tag', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_tag', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_tag', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_tag', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_prev_opponent_tag', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_prev_opponent_tag', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_prev_opponent_tag', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_prev_opponent_tag', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_logo', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_logo', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_logo', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_logo', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_prev_opponent_logo', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_prev_opponent_logo', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_prev_opponent_logo', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_prev_opponent_logo', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_prev_opponent_id', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_prev_opponent_id', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_prev_opponent_id', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_prev_opponent_id', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_prev_match_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_prev_match_score', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_prev_match_opponent_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_prev_match_opponent_score', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_prev_match_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_prev_match_score', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_prev_match_opponent_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_prev_match_opponent_score', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phase_type', full_name='CMsgDOTATournamentInfo.UpcomingMatch.phase_type', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team1_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team1_score', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team2_score', full_name='CMsgDOTATournamentInfo.UpcomingMatch.team2_score', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=667,
  serialized_end=1316,
)

_CMSGDOTATOURNAMENTINFO_NEWS = _descriptor.Descriptor(
  name='News',
  full_name='CMsgDOTATournamentInfo.News',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='CMsgDOTATournamentInfo.News.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CMsgDOTATournamentInfo.News.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='CMsgDOTATournamentInfo.News.image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTATournamentInfo.News.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1387,
)

_CMSGDOTATOURNAMENTINFO = _descriptor.Descriptor(
  name='CMsgDOTATournamentInfo',
  full_name='CMsgDOTATournamentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTATournamentInfo.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phase_list', full_name='CMsgDOTATournamentInfo.phase_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams_list', full_name='CMsgDOTATournamentInfo.teams_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upcoming_matches_list', full_name='CMsgDOTATournamentInfo.upcoming_matches_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='news_list', full_name='CMsgDOTATournamentInfo.news_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTATOURNAMENTINFO_PHASEGROUP, _CMSGDOTATOURNAMENTINFO_PHASE, _CMSGDOTATOURNAMENTINFO_TEAM, _CMSGDOTATOURNAMENTINFO_UPCOMINGMATCH, _CMSGDOTATOURNAMENTINFO_NEWS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=1387,
)


_CMSGREQUESTWEEKENDTOURNEYSCHEDULE = _descriptor.Descriptor(
  name='CMsgRequestWeekendTourneySchedule',
  full_name='CMsgRequestWeekendTourneySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1424,
)


_CMSGWEEKENDTOURNEYSCHEDULE_DIVISION = _descriptor.Descriptor(
  name='Division',
  full_name='CMsgWeekendTourneySchedule.Division',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='division_code', full_name='CMsgWeekendTourneySchedule.Division.division_code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_window_open', full_name='CMsgWeekendTourneySchedule.Division.time_window_open', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_window_close', full_name='CMsgWeekendTourneySchedule.Division.time_window_close', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_window_open_next', full_name='CMsgWeekendTourneySchedule.Division.time_window_open_next', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1631,
)

_CMSGWEEKENDTOURNEYSCHEDULE = _descriptor.Descriptor(
  name='CMsgWeekendTourneySchedule',
  full_name='CMsgWeekendTourneySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='divisions', full_name='CMsgWeekendTourneySchedule.divisions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGWEEKENDTOURNEYSCHEDULE_DIVISION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1631,
)


_CMSGWEEKENDTOURNEYOPTS = _descriptor.Descriptor(
  name='CMsgWeekendTourneyOpts',
  full_name='CMsgWeekendTourneyOpts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='participating', full_name='CMsgWeekendTourneyOpts.participating', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='division_id', full_name='CMsgWeekendTourneyOpts.division_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buyin', full_name='CMsgWeekendTourneyOpts.buyin', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='CMsgWeekendTourneyOpts.skill_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_groups', full_name='CMsgWeekendTourneyOpts.match_groups', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgWeekendTourneyOpts.team_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickup_team_name', full_name='CMsgWeekendTourneyOpts.pickup_team_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickup_team_logo', full_name='CMsgWeekendTourneyOpts.pickup_team_logo', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1829,
)


_CMSGWEEKENDTOURNEYLEAVE = _descriptor.Descriptor(
  name='CMsgWeekendTourneyLeave',
  full_name='CMsgWeekendTourneyLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1831,
  serialized_end=1856,
)


_CMSGDOTATOURNAMENT_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CMsgDOTATournament.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_gid', full_name='CMsgDOTATournament.Team.team_gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node_or_state', full_name='CMsgDOTATournament.Team.node_or_state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTATournament.Team.players', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='player_buyin', full_name='CMsgDOTATournament.Team.player_buyin', index=3,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='player_skill_level', full_name='CMsgDOTATournament.Team.player_skill_level', index=4,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='match_group_mask', full_name='CMsgDOTATournament.Team.match_group_mask', index=5,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTATournament.Team.team_id', index=6,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTATournament.Team.team_name', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_base_logo', full_name='CMsgDOTATournament.Team.team_base_logo', index=8,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_ui_logo', full_name='CMsgDOTATournament.Team.team_ui_logo', index=9,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_date', full_name='CMsgDOTATournament.Team.team_date', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2283,
  serialized_end=2536,
)

_CMSGDOTATOURNAMENT_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CMsgDOTATournament.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_idx', full_name='CMsgDOTATournament.Game.node_idx', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgDOTATournament.Game.lobby_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTATournament.Game.match_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_a_good', full_name='CMsgDOTATournament.Game.team_a_good', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgDOTATournament.Game.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTATournament.Game.start_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2539,
  serialized_end=2710,
)

_CMSGDOTATOURNAMENT_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='CMsgDOTATournament.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='CMsgDOTATournament.Node.node_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_idx_a', full_name='CMsgDOTATournament.Node.team_idx_a', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_idx_b', full_name='CMsgDOTATournament.Node.team_idx_b', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node_state', full_name='CMsgDOTATournament.Node.node_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2713,
  serialized_end=2851,
)

_CMSGDOTATOURNAMENT = _descriptor.Descriptor(
  name='CMsgDOTATournament',
  full_name='CMsgDOTATournament',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTATournament.tournament_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='division_id', full_name='CMsgDOTATournament.division_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='schedule_time', full_name='CMsgDOTATournament.schedule_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='CMsgDOTATournament.skill_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_template', full_name='CMsgDOTATournament.tournament_template', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgDOTATournament.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state_seq_num', full_name='CMsgDOTATournament.state_seq_num', index=6,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_trophy_id', full_name='CMsgDOTATournament.season_trophy_id', index=7,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTATournament.teams', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgDOTATournament.games', index=9,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='CMsgDOTATournament.nodes', index=10,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTATOURNAMENT_TEAM, _CMSGDOTATOURNAMENT_GAME, _CMSGDOTATOURNAMENT_NODE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=2851,
)


_CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE = _descriptor.Descriptor(
  name='GameChange',
  full_name='CMsgDOTATournamentStateChange.GameChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTATournamentStateChange.GameChange.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_state', full_name='CMsgDOTATournamentStateChange.GameChange.new_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3238,
  serialized_end=3342,
)

_CMSGDOTATOURNAMENTSTATECHANGE_TEAMCHANGE = _descriptor.Descriptor(
  name='TeamChange',
  full_name='CMsgDOTATournamentStateChange.TeamChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_gid', full_name='CMsgDOTATournamentStateChange.TeamChange.team_gid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_node_or_state', full_name='CMsgDOTATournamentStateChange.TeamChange.new_node_or_state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='old_node_or_state', full_name='CMsgDOTATournamentStateChange.TeamChange.old_node_or_state', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3344,
  serialized_end=3428,
)

_CMSGDOTATOURNAMENTSTATECHANGE = _descriptor.Descriptor(
  name='CMsgDOTATournamentStateChange',
  full_name='CMsgDOTATournamentStateChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_tournament_id', full_name='CMsgDOTATournamentStateChange.new_tournament_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event', full_name='CMsgDOTATournamentStateChange.event', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_tournament_state', full_name='CMsgDOTATournamentStateChange.new_tournament_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_changes', full_name='CMsgDOTATournamentStateChange.game_changes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_changes', full_name='CMsgDOTATournamentStateChange.team_changes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='merged_tournament_ids', full_name='CMsgDOTATournamentStateChange.merged_tournament_ids', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='state_seq_num', full_name='CMsgDOTATournamentStateChange.state_seq_num', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE, _CMSGDOTATOURNAMENTSTATECHANGE_TEAMCHANGE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2854,
  serialized_end=3428,
)


_CMSGDOTATOURNAMENTREQUEST = _descriptor.Descriptor(
  name='CMsgDOTATournamentRequest',
  full_name='CMsgDOTATournamentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTATournamentRequest.tournament_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_tournament_gid', full_name='CMsgDOTATournamentRequest.client_tournament_gid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3430,
  serialized_end=3511,
)


_CMSGDOTATOURNAMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTATournamentResponse',
  full_name='CMsgDOTATournamentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTATournamentResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament', full_name='CMsgDOTATournamentResponse.tournament', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3513,
  serialized_end=3601,
)


_CMSGDOTACLEARTOURNAMENTGAME = _descriptor.Descriptor(
  name='CMsgDOTAClearTournamentGame',
  full_name='CMsgDOTAClearTournamentGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTAClearTournamentGame.tournament_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgDOTAClearTournamentGame.game_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3603,
  serialized_end=3672,
)


_CMSGDOTAWEEKENDTOURNEYPLAYERSKILLLEVELSTATS = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats',
  full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.skill_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_won_0', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_won_0', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_won_1', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_won_1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_won_2', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_won_2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_won_3', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_won_3', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_bye_and_lost', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_bye_and_lost', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_bye_and_won', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.times_bye_and_won', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_games_won', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.total_games_won', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAWeekendTourneyPlayerSkillLevelStats.score', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3675,
  serialized_end=3920,
)


_CMSGDOTAWEEKENDTOURNEYPLAYERSTATS = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyPlayerStats',
  full_name='CMsgDOTAWeekendTourneyPlayerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAWeekendTourneyPlayerStats.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_trophy_id', full_name='CMsgDOTAWeekendTourneyPlayerStats.season_trophy_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill_levels', full_name='CMsgDOTAWeekendTourneyPlayerStats.skill_levels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_tier', full_name='CMsgDOTAWeekendTourneyPlayerStats.current_tier', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3923,
  serialized_end=4094,
)


_CMSGDOTAWEEKENDTOURNEYPLAYERSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyPlayerStatsRequest',
  full_name='CMsgDOTAWeekendTourneyPlayerStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAWeekendTourneyPlayerStatsRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_trophy_id', full_name='CMsgDOTAWeekendTourneyPlayerStatsRequest.season_trophy_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4096,
  serialized_end=4184,
)


_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORYREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyPlayerHistoryRequest',
  full_name='CMsgDOTAWeekendTourneyPlayerHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAWeekendTourneyPlayerHistoryRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_trophy_id', full_name='CMsgDOTAWeekendTourneyPlayerHistoryRequest.season_trophy_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4186,
  serialized_end=4276,
)


_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY_TOURNAMENT = _descriptor.Descriptor(
  name='Tournament',
  full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.tournament_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_tier', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.tournament_tier', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.team_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_date', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.team_date', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_result', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.team_result', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.account_id', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.team_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_trophy_id', full_name='CMsgDOTAWeekendTourneyPlayerHistory.Tournament.season_trophy_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4409,
  serialized_end=4611,
)

_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyPlayerHistory',
  full_name='CMsgDOTAWeekendTourneyPlayerHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAWeekendTourneyPlayerHistory.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournaments', full_name='CMsgDOTAWeekendTourneyPlayerHistory.tournaments', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY_TOURNAMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4279,
  serialized_end=4611,
)


_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_TIER = _descriptor.Descriptor(
  name='Tier',
  full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tier', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.tier', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.players', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.teams', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='winning_teams', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.winning_teams', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_streak_2', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.players_streak_2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_streak_3', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.players_streak_3', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_streak_4', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.players_streak_4', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_streak_5', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Tier.players_streak_5', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4734,
  serialized_end=4913,
)

_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION = _descriptor.Descriptor(
  name='Division',
  full_name='CMsgDOTAWeekendTourneyParticipationDetails.Division',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='division_id', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Division.division_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='schedule_time', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Division.schedule_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tiers', full_name='CMsgDOTAWeekendTourneyParticipationDetails.Division.tiers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4915,
  serialized_end=5034,
)

_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS = _descriptor.Descriptor(
  name='CMsgDOTAWeekendTourneyParticipationDetails',
  full_name='CMsgDOTAWeekendTourneyParticipationDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='divisions', full_name='CMsgDOTAWeekendTourneyParticipationDetails.divisions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_TIER, _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4614,
  serialized_end=5034,
)

_CMSGDOTATOURNAMENTINFO_PHASEGROUP.containing_type = _CMSGDOTATOURNAMENTINFO
_CMSGDOTATOURNAMENTINFO_PHASE.fields_by_name['group_list'].message_type = _CMSGDOTATOURNAMENTINFO_PHASEGROUP
_CMSGDOTATOURNAMENTINFO_PHASE.containing_type = _CMSGDOTATOURNAMENTINFO
_CMSGDOTATOURNAMENTINFO_TEAM.containing_type = _CMSGDOTATOURNAMENTINFO
_CMSGDOTATOURNAMENTINFO_UPCOMINGMATCH.containing_type = _CMSGDOTATOURNAMENTINFO
_CMSGDOTATOURNAMENTINFO_NEWS.containing_type = _CMSGDOTATOURNAMENTINFO
_CMSGDOTATOURNAMENTINFO.fields_by_name['phase_list'].message_type = _CMSGDOTATOURNAMENTINFO_PHASE
_CMSGDOTATOURNAMENTINFO.fields_by_name['teams_list'].message_type = _CMSGDOTATOURNAMENTINFO_TEAM
_CMSGDOTATOURNAMENTINFO.fields_by_name['upcoming_matches_list'].message_type = _CMSGDOTATOURNAMENTINFO_UPCOMINGMATCH
_CMSGDOTATOURNAMENTINFO.fields_by_name['news_list'].message_type = _CMSGDOTATOURNAMENTINFO_NEWS
_CMSGWEEKENDTOURNEYSCHEDULE_DIVISION.containing_type = _CMSGWEEKENDTOURNEYSCHEDULE
_CMSGWEEKENDTOURNEYSCHEDULE.fields_by_name['divisions'].message_type = _CMSGWEEKENDTOURNEYSCHEDULE_DIVISION
_CMSGDOTATOURNAMENT_TEAM.containing_type = _CMSGDOTATOURNAMENT
_CMSGDOTATOURNAMENT_GAME.fields_by_name['state'].enum_type = dota__client__enums__pb2._ETOURNAMENTGAMESTATE
_CMSGDOTATOURNAMENT_GAME.containing_type = _CMSGDOTATOURNAMENT
_CMSGDOTATOURNAMENT_NODE.fields_by_name['node_state'].enum_type = dota__client__enums__pb2._ETOURNAMENTNODESTATE
_CMSGDOTATOURNAMENT_NODE.containing_type = _CMSGDOTATOURNAMENT
_CMSGDOTATOURNAMENT.fields_by_name['tournament_template'].enum_type = dota__client__enums__pb2._ETOURNAMENTTEMPLATE
_CMSGDOTATOURNAMENT.fields_by_name['state'].enum_type = dota__client__enums__pb2._ETOURNAMENTSTATE
_CMSGDOTATOURNAMENT.fields_by_name['teams'].message_type = _CMSGDOTATOURNAMENT_TEAM
_CMSGDOTATOURNAMENT.fields_by_name['games'].message_type = _CMSGDOTATOURNAMENT_GAME
_CMSGDOTATOURNAMENT.fields_by_name['nodes'].message_type = _CMSGDOTATOURNAMENT_NODE
_CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE.fields_by_name['new_state'].enum_type = dota__client__enums__pb2._ETOURNAMENTGAMESTATE
_CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE.containing_type = _CMSGDOTATOURNAMENTSTATECHANGE
_CMSGDOTATOURNAMENTSTATECHANGE_TEAMCHANGE.containing_type = _CMSGDOTATOURNAMENTSTATECHANGE
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['event'].enum_type = _ETOURNAMENTEVENT
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['new_tournament_state'].enum_type = dota__client__enums__pb2._ETOURNAMENTSTATE
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['game_changes'].message_type = _CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['team_changes'].message_type = _CMSGDOTATOURNAMENTSTATECHANGE_TEAMCHANGE
_CMSGDOTATOURNAMENTRESPONSE.fields_by_name['tournament'].message_type = _CMSGDOTATOURNAMENT
_CMSGDOTAWEEKENDTOURNEYPLAYERSTATS.fields_by_name['skill_levels'].message_type = _CMSGDOTAWEEKENDTOURNEYPLAYERSKILLLEVELSTATS
_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY_TOURNAMENT.containing_type = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY
_CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY.fields_by_name['tournaments'].message_type = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY_TOURNAMENT
_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_TIER.containing_type = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS
_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION.fields_by_name['tiers'].message_type = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_TIER
_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION.containing_type = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS
_CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS.fields_by_name['divisions'].message_type = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION
DESCRIPTOR.message_types_by_name['CMsgDOTATournamentInfo'] = _CMSGDOTATOURNAMENTINFO
DESCRIPTOR.message_types_by_name['CMsgRequestWeekendTourneySchedule'] = _CMSGREQUESTWEEKENDTOURNEYSCHEDULE
DESCRIPTOR.message_types_by_name['CMsgWeekendTourneySchedule'] = _CMSGWEEKENDTOURNEYSCHEDULE
DESCRIPTOR.message_types_by_name['CMsgWeekendTourneyOpts'] = _CMSGWEEKENDTOURNEYOPTS
DESCRIPTOR.message_types_by_name['CMsgWeekendTourneyLeave'] = _CMSGWEEKENDTOURNEYLEAVE
DESCRIPTOR.message_types_by_name['CMsgDOTATournament'] = _CMSGDOTATOURNAMENT
DESCRIPTOR.message_types_by_name['CMsgDOTATournamentStateChange'] = _CMSGDOTATOURNAMENTSTATECHANGE
DESCRIPTOR.message_types_by_name['CMsgDOTATournamentRequest'] = _CMSGDOTATOURNAMENTREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTATournamentResponse'] = _CMSGDOTATOURNAMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAClearTournamentGame'] = _CMSGDOTACLEARTOURNAMENTGAME
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyPlayerSkillLevelStats'] = _CMSGDOTAWEEKENDTOURNEYPLAYERSKILLLEVELSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyPlayerStats'] = _CMSGDOTAWEEKENDTOURNEYPLAYERSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyPlayerStatsRequest'] = _CMSGDOTAWEEKENDTOURNEYPLAYERSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyPlayerHistoryRequest'] = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORYREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyPlayerHistory'] = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTAWeekendTourneyParticipationDetails'] = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS
DESCRIPTOR.enum_types_by_name['ETournamentEvent'] = _ETOURNAMENTEVENT

CMsgDOTATournamentInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTATournamentInfo', (_message.Message,), dict(

  PhaseGroup = _reflection.GeneratedProtocolMessageType('PhaseGroup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTINFO_PHASEGROUP,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo.PhaseGroup)
    ))
  ,

  Phase = _reflection.GeneratedProtocolMessageType('Phase', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTINFO_PHASE,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo.Phase)
    ))
  ,

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTINFO_TEAM,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo.Team)
    ))
  ,

  UpcomingMatch = _reflection.GeneratedProtocolMessageType('UpcomingMatch', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTINFO_UPCOMINGMATCH,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo.UpcomingMatch)
    ))
  ,

  News = _reflection.GeneratedProtocolMessageType('News', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTINFO_NEWS,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo.News)
    ))
  ,
  DESCRIPTOR = _CMSGDOTATOURNAMENTINFO,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATournamentInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTATournamentInfo)
_sym_db.RegisterMessage(CMsgDOTATournamentInfo.PhaseGroup)
_sym_db.RegisterMessage(CMsgDOTATournamentInfo.Phase)
_sym_db.RegisterMessage(CMsgDOTATournamentInfo.Team)
_sym_db.RegisterMessage(CMsgDOTATournamentInfo.UpcomingMatch)
_sym_db.RegisterMessage(CMsgDOTATournamentInfo.News)

CMsgRequestWeekendTourneySchedule = _reflection.GeneratedProtocolMessageType('CMsgRequestWeekendTourneySchedule', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTWEEKENDTOURNEYSCHEDULE,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestWeekendTourneySchedule)
  ))
_sym_db.RegisterMessage(CMsgRequestWeekendTourneySchedule)

CMsgWeekendTourneySchedule = _reflection.GeneratedProtocolMessageType('CMsgWeekendTourneySchedule', (_message.Message,), dict(

  Division = _reflection.GeneratedProtocolMessageType('Division', (_message.Message,), dict(
    DESCRIPTOR = _CMSGWEEKENDTOURNEYSCHEDULE_DIVISION,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgWeekendTourneySchedule.Division)
    ))
  ,
  DESCRIPTOR = _CMSGWEEKENDTOURNEYSCHEDULE,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgWeekendTourneySchedule)
  ))
_sym_db.RegisterMessage(CMsgWeekendTourneySchedule)
_sym_db.RegisterMessage(CMsgWeekendTourneySchedule.Division)

CMsgWeekendTourneyOpts = _reflection.GeneratedProtocolMessageType('CMsgWeekendTourneyOpts', (_message.Message,), dict(
  DESCRIPTOR = _CMSGWEEKENDTOURNEYOPTS,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgWeekendTourneyOpts)
  ))
_sym_db.RegisterMessage(CMsgWeekendTourneyOpts)

CMsgWeekendTourneyLeave = _reflection.GeneratedProtocolMessageType('CMsgWeekendTourneyLeave', (_message.Message,), dict(
  DESCRIPTOR = _CMSGWEEKENDTOURNEYLEAVE,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgWeekendTourneyLeave)
  ))
_sym_db.RegisterMessage(CMsgWeekendTourneyLeave)

CMsgDOTATournament = _reflection.GeneratedProtocolMessageType('CMsgDOTATournament', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENT_TEAM,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournament.Team)
    ))
  ,

  Game = _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENT_GAME,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournament.Game)
    ))
  ,

  Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENT_NODE,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournament.Node)
    ))
  ,
  DESCRIPTOR = _CMSGDOTATOURNAMENT,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATournament)
  ))
_sym_db.RegisterMessage(CMsgDOTATournament)
_sym_db.RegisterMessage(CMsgDOTATournament.Team)
_sym_db.RegisterMessage(CMsgDOTATournament.Game)
_sym_db.RegisterMessage(CMsgDOTATournament.Node)

CMsgDOTATournamentStateChange = _reflection.GeneratedProtocolMessageType('CMsgDOTATournamentStateChange', (_message.Message,), dict(

  GameChange = _reflection.GeneratedProtocolMessageType('GameChange', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTSTATECHANGE_GAMECHANGE,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentStateChange.GameChange)
    ))
  ,

  TeamChange = _reflection.GeneratedProtocolMessageType('TeamChange', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTATOURNAMENTSTATECHANGE_TEAMCHANGE,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTATournamentStateChange.TeamChange)
    ))
  ,
  DESCRIPTOR = _CMSGDOTATOURNAMENTSTATECHANGE,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATournamentStateChange)
  ))
_sym_db.RegisterMessage(CMsgDOTATournamentStateChange)
_sym_db.RegisterMessage(CMsgDOTATournamentStateChange.GameChange)
_sym_db.RegisterMessage(CMsgDOTATournamentStateChange.TeamChange)

CMsgDOTATournamentRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTATournamentRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATOURNAMENTREQUEST,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATournamentRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTATournamentRequest)

CMsgDOTATournamentResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTATournamentResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTATOURNAMENTRESPONSE,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTATournamentResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTATournamentResponse)

CMsgDOTAClearTournamentGame = _reflection.GeneratedProtocolMessageType('CMsgDOTAClearTournamentGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLEARTOURNAMENTGAME,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAClearTournamentGame)
  ))
_sym_db.RegisterMessage(CMsgDOTAClearTournamentGame)

CMsgDOTAWeekendTourneyPlayerSkillLevelStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyPlayerSkillLevelStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERSKILLLEVELSTATS,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerSkillLevelStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerSkillLevelStats)

CMsgDOTAWeekendTourneyPlayerStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyPlayerStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERSTATS,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerStats)

CMsgDOTAWeekendTourneyPlayerStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyPlayerStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerStatsRequest)

CMsgDOTAWeekendTourneyPlayerHistoryRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyPlayerHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORYREQUEST,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerHistoryRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerHistoryRequest)

CMsgDOTAWeekendTourneyPlayerHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyPlayerHistory', (_message.Message,), dict(

  Tournament = _reflection.GeneratedProtocolMessageType('Tournament', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY_TOURNAMENT,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerHistory.Tournament)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPLAYERHISTORY,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyPlayerHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerHistory)
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyPlayerHistory.Tournament)

CMsgDOTAWeekendTourneyParticipationDetails = _reflection.GeneratedProtocolMessageType('CMsgDOTAWeekendTourneyParticipationDetails', (_message.Message,), dict(

  Tier = _reflection.GeneratedProtocolMessageType('Tier', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_TIER,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyParticipationDetails.Tier)
    ))
  ,

  Division = _reflection.GeneratedProtocolMessageType('Division', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS_DIVISION,
    __module__ = 'dota_gcmessages_client_tournament_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyParticipationDetails.Division)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAWEEKENDTOURNEYPARTICIPATIONDETAILS,
  __module__ = 'dota_gcmessages_client_tournament_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWeekendTourneyParticipationDetails)
  ))
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyParticipationDetails)
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyParticipationDetails.Tier)
_sym_db.RegisterMessage(CMsgDOTAWeekendTourneyParticipationDetails.Division)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['players'].has_options = True
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['players']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['player_buyin'].has_options = True
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['player_buyin']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['player_skill_level'].has_options = True
_CMSGDOTATOURNAMENT_TEAM.fields_by_name['player_skill_level']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['merged_tournament_ids'].has_options = True
_CMSGDOTATOURNAMENTSTATECHANGE.fields_by_name['merged_tournament_ids']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



from dota2.enums import EGCBaseMsg, EDOTAGCMsg, ESOType


class Party(object):
    EVENT_PARTY_INVITE = 'party_invite'
    """When a party invite is receieved

    :param message: `CSODOTAPartyInvite <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L83>`_
    :type  message: proto message
    """
    EVENT_NEW_PARTY = 'new_party'
    """Entered a party, either by inviting someone or accepting an invite

    :param message: `CSODOTAParty <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L32>`_
    :type  message: proto message
    """
    EVENT_PARTY_CHANGED = 'party_changed'
    """Anything changes to the party state, leaving/entering/invites etc

    :param message: `CSODOTAParty <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L32>`_
    :type  message: proto message
    """
    EVENT_PARTY_REMOVED = 'party_removed'
    """Left party, either left, kicked or disbanded

    :param message: `CSODOTAParty <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L32>`_
    :type  message: proto message
    """
    EVENT_INVITATION_CREATED = 'invitation_created'
    """After inviting another user

    :param message: `CMsgInvitationCreated <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/base_gcmessages.proto#L93>`_
    :type  message: proto message
    """

    party = None

    def __init__(self):
        super(Party, self).__init__()
        self.on('notready', self.__party_cleanup)
        self.socache.on(('new', ESOType.CSODOTAPartyInvite), self.__handle_party_invite)
        self.socache.on(('new', ESOType.CSODOTAParty), self.__handle_party_new)
        self.socache.on(('updated', ESOType.CSODOTAParty), self.__handle_party_changed)
        self.socache.on(('removed', ESOType.CSODOTAParty), self.__handle_party_removed)

        self.on(EGCBaseMsg.EMsgGCInvitationCreated, self.__handle_invitation_created)

    def __party_cleanup(self):
        self.party = None

    def __handle_party_invite(self, message):
        self.emit('party_invite', message)

    def __handle_party_new(self, message):
        self.party = message
        self.emit('new_party', message)

    def __handle_party_changed(self, message):
        self.party = message
        self.emit('party_changed', message)

    def __handle_party_removed(self, message):
        self.party = None
        self.emit('party_removed', message)

    def __handle_invitation_created(self, message):
        self.emit('invitation_created', message)

    def respond_to_party_invite(self, party_id, accept=False):
        """
        Respond to a party invite.

        :param party_id: party id
        :param accept: accept
        """
        if self.verbose_debug:
            self._LOG.debug("Responding to party invite %s, accept: %s" % (party_id, accept))

        self.send(EGCBaseMsg.EMsgGCPartyInviteResponse, {
            "party_id": party_id,
            "accept": accept
        })

    def leave_party(self):
        """
        Leaves the current party.

        :return: job event id
        :rtype: str
        """
        if self.verbose_debug:
            self._LOG.debug("Leaving party.")

        self.send(EGCBaseMsg.EMsgGCLeaveParty, {})

    def set_party_leader(self, steam_id):
        """
        Set the new party leader.

        :param steam_id: steam_id
        :return: job event id
        :rtype: str
        """
        if not self.party: return

        if self.verbose_debug:
            self._LOG.debug("Setting party leader: %s" % steam_id)

        self.send(EDOTAGCMsg.EMsgClientToGCSetPartyLeader, {
            "new_leader_steamid": steam_id
        })

    def set_party_coach_flag(self, coach):
        """
        Set the bot's status as a coach.

        :param coach: bool
        :return: job event id
        :rtype: str

        Response event: ``party_coach``

        :param steam_id: steam_id for response
        :type  steam_id: :class:`int`

        :param message: `CMsgDOTAPartyMemberSetCoach <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_match_management.proto#L354>`_ proto message
        """
        if not self.party or self.party.leader_id != self.steam.steam_id: return

        if self.verbose_debug:
            self._LOG.debug("Setting coach flag to: %s" % coach)

        self.send(EDOTAGCMsg.EMsgGCPartyMemberSetCoach, {
            "wants_coach": coach
        })

    def invite_to_party(self, steam_id):
        """
        Invites a player to a party. This will create a new party if you aren't in one.

        :param steam_id: steam_id
        :return: job event id
        :rtype: str

        Response event: ``invite_to_party``

        :param message: `CMsgInvitationCreated <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/base_gcmessages.proto#L93>`_ proto message
        """
        if self.party and self.party.leader_id != self.steam.steam_id: return

        if self.verbose_debug:
            self._LOG.debug("Inviting %s to a party." % steam_id)

        jobid = self.send_job(EGCBaseMsg.EMsgGCInviteToParty, {
            "steam_id": steam_id
        })

        @self.once(jobid)
        def wrap_invite_to_party(message):
            self.emit('invitation_created', message)

        return jobid

    def kick_from_party(self, steam_id):
        """
        Kicks a player from the party. This will create a new party
        if you aren't in one.

        :param steam_id: steam_id
        :return: job event id
        :rtype: str

        Response event: ``kick_from_party``

        :param steam_id: steam_id for response
        :type  steam_id: :class:`int`

        :param message: `CMsgKickFromParty <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/base_gcmessages.proto#L114>`_ proto message
        """
        if (not self.party
            or self.party.leader_id != self.steam.steam_id
            or steam_id not in self.party.memeber_ids): return

        if self.verbose_debug:
            self._LOG.debug("Kicking %s from the party." % steam_id)

        self.send(EGCBaseMsg.EMsgGCKickFromParty, {
            "steam_id": steam_id
        })



from steam.enums import EResult
from dota2.enums import EDOTAGCMsg

class Match(object):
    def __init__(self):
        super(Match, self).__init__()

        # register our handlers
        self.on(EDOTAGCMsg.EMsgGCMatchmakingStatsResponse,             self.__handle_mmstats)
        self.on(EDOTAGCMsg.EMsgGCToClientFindTopSourceTVGamesResponse, self.__handle_top_source_tv)
        self.on(EDOTAGCMsg.EMsgDOTAGetPlayerMatchHistoryResponse,      self.__handle_player_match_history)
        self.on(EDOTAGCMsg.EMsgGCRequestMatches,                       self.__handle_matches)
        self.on(EDOTAGCMsg.EMsgClientToGCMatchesMinimalResponse,       self.__handle_matches_minimal)

    def request_matchmaking_stats(self):
        """
        Request matchmaking statistics

        Response event: ``matchmaking_stats``

        :param message: `CMsgDOTAMatchmakingStatsResponse <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L607-L611>`_
        :type  message: proto message
        """
        self.send(EDOTAGCMsg.EMsgGCMatchmakingStatsRequest)

    def __handle_mmstats(self, message):
        self.emit("matchmaking_stats", message)

    def request_match_details(self, match_id):
        """Request match details for a specific match

        .. note::
            Rate limited to 100 requests/day

        :param match_id: match id
        :type  match_id: :class:`int`
        :return: job event id
        :rtype: :class:`str`

        Response event: ``match_details``

        :param match_id: match_id for response
        :type  match_id: :class:`int`
        :param eresult: result enum
        :type  eresult: :class:`steam.enums.EResult`
        :param match: `CMsgDOTAMatch <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_common.proto#L866-L1001>`_
        :type  match: proto message
        """
        jobid = self.send_job(EDOTAGCMsg.EMsgGCMatchDetailsRequest, {
                              'match_id': match_id,
                              })

        def wrap_match_details(message):
            eresult = EResult(message.result)
            match = message.match if eresult == EResult.OK else None
            self.emit('match_details', match_id, eresult, match)

        self.once(jobid, wrap_match_details)

        return jobid


    def request_matches(self, **kwargs):
        """Request matches. For arguments see `CMsgDOTARequestMatches <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L81-L103>`_

        .. note::
            Rate limited to 50 requests/day

        .. warning::
            Some of the arguments don't work. Ask Valve

        :return: job event id
        :rtype: :class:`str`

        Response event: ``matches``

        :param message: `CMsgDOTARequestMatchesResponse <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L105-L117>`_
        :type  message: proto message
        """
        return self.send_job(EDOTAGCMsg.EMsgGCRequestMatches, kwargs)

    def __handle_matches(self, message):
        self.emit('matches', message)

    def request_matches_minimal(self, match_ids):
        """
        Request matches with only minimal data.

        :param match_ids: match ids
        :type  match_ids: :class:`list`
        :return: job event id
        :rtype: :class:`str`

        Response event: ``matches_minimal``

        :param matches: list of `CMsgDOTAMatchMinimal <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_watch.proto#L120-L154>`_
        :type  matches: :class:`list`

        """
        return self.send_job(EDOTAGCMsg.EMsgClientToGCMatchesMinimalRequest, {'match_ids': match_ids})

    def __handle_matches_minimal(self, message):
        self.emit('matches_minimal', message.matches)

    def request_top_source_tv_games(self, **kwargs):
        """
        Find top source TV games. For arguments see `CMsgClientToGCFindTopSourceTVGames <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_watch.proto#L42-L49>`_

        Response event: ``top_source_tv_games``

        :param response: `CMsgGCToClientFindTopSourceTVGamesResponse <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_watch.proto#L51-L60>`_
        :type  response: proto message
        """
        self.send(EDOTAGCMsg.EMsgClientToGCFindTopSourceTVGames, kwargs)

    def __handle_top_source_tv(self, message):
        self.emit("top_source_tv_games", message)

    def request_player_match_history(self, **kwargs):
        """Request player match history

        :param account_id: account id
        :type  account_id: :class:`int`
        :param start_at_match_id: matches from before this match id (``0`` for latest)
        :type  start_at_match_id: :class:`int`
        :param matches_requested: number of matches to return
        :type  matches_requested: :class:`int`
        :param hero_id: filter by hero id
        :type  hero_id: :class:`int`
        :param request_id: request id to match with the response with the request
        :type  request_id: :class:`int`
        :param include_practice_matches: whether to include practive matches
        :type  include_practice_matches: :class:`bool`
        :param include_custom_games: whether to include custom matches
        :type  include_custom_games: :class:`bool`

        Response event: ``player_match_history``

        :param request_id: request id from the reuqest
        :type  request_id: :class:`int`
        :param matches: `CMsgDOTAGetPlayerMatchHistoryResponse.matches <https://github.com/ValvePython/dota2/blob/15729f58ac4ebbfad90414d43ef593eadd355b25/protobufs/dota_gcmessages_client.proto#L907-L934>`_
        :type  matches: :class:`list`

        """
        self.send(EDOTAGCMsg.EMsgDOTAGetPlayerMatchHistory, kwargs)

    def __handle_player_match_history(self, message):
        self.emit('player_match_history', message.request_id, message.matches)

